@@ -1,26 +1,27 @@
-;;; gitattributes-mode.el --- Major mode for editing .gitattributes files  -*- lexical-binding: t -*-
+;;; gitattributes-mode.el --- Major mode for editing .gitattributes files  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2013-2015  Rüdiger Sonderfeld
-;; Copyright (C) 2013-2021  The Magit Project Contributors
+;; Copyright (C) 2013-2015 Rüdiger Sonderfeld
+;; Copyright (C) 2013-2023 The Magit Project Contributors
 
 ;; Author: Rüdiger Sonderfeld <ruediger@c-plusplus.net>
 ;; Maintainer: Jonas Bernoulli <jonas@bernoul.li>
 ;; Homepage: https://github.com/magit/git-modes
 ;; Keywords: convenience vc git
+
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
-;; This file is free software; you can redistribute it and/or modify
+;; This file is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 3 of the License,
+;; by the Free Software Foundation, either version 3 of the License,
 ;; or (at your option) any later version.
-
+;;
 ;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
-
+;;
 ;; You should have received a copy of the GNU General Public License
-;; along with this file.  If not, see <http://www.gnu.org/licenses/>.
+;; along with this file.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -30,6 +31,7 @@
 
 ;;; Code:
 
+(require 'compat)
 (require 'easymenu)
 (require 'thingatpt)
 
@@ -183,8 +185,8 @@ If ARG is omitted or nil, move point backward one field."
     (dotimes (_ (or arg 1))
       (re-search-backward "\\s-[!-]?\\<" nil 'move))))
 
-(defvar gitattributes-mode-map (make-sparse-keymap)
-  "Keymap for `gitattributes-mode'.")
+(defvar-keymap gitattributes-mode-map
+  :doc "Keymap for `gitattributes-mode'.")
 
 (easy-menu-define gitattributes-mode-menu
   gitattributes-mode-map
